package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.InvestigateDispositionTable;

/**
 * 考察配置与考察主关联Service接口
 * 
 * @author ruoyi
 * @date 2023-10-10
 */
public interface IInvestigateDispositionTableService 
{
    /**
     * 查询考察配置与考察主关联
     * 
     * @param investigateTableId 考察配置与考察主关联主键
     * @return 考察配置与考察主关联
     */
    public InvestigateDispositionTable selectInvestigateDispositionTableByInvestigateTableId(Long investigateTableId);

    /**
     * 查询考察配置与考察主关联列表
     * 
     * @param investigateDispositionTable 考察配置与考察主关联
     * @return 考察配置与考察主关联集合
     */
    public List<InvestigateDispositionTable> selectInvestigateDispositionTableList(InvestigateDispositionTable investigateDispositionTable);

    /**
     * 新增考察配置与考察主关联
     * 
     * @param investigateDispositionTable 考察配置与考察主关联
     * @return 结果
     */
    public int insertInvestigateDispositionTable(InvestigateDispositionTable investigateDispositionTable);

    /**
     * 修改考察配置与考察主关联
     * 
     * @param investigateDispositionTable 考察配置与考察主关联
     * @return 结果
     */
    public int updateInvestigateDispositionTable(InvestigateDispositionTable investigateDispositionTable);

    /**
     * 批量删除考察配置与考察主关联
     * 
     * @param investigateDispositionTable 需要删除的考察配置与考察主关联主键集合
     * @return 结果
     */
    public int deleteInvestigateDispositionTableByInvestigateTableIds(InvestigateDispositionTable investigateDispositionTable);

    /**
     * 删除考察配置与考察主关联信息
     * 
     * @param investigateTableId 考察配置与考察主关联主键
     * @return 结果
     */
    public int deleteInvestigateDispositionTableByInvestigateTableId(Long investigateTableId);
}
